@@ -5,6 +5,7 @@ import calendar
 from dataclasses import dataclass
 from datetime import date as _date
 from datetime import datetime as _datetime
+from datetime import timedelta as _timedelta
 from typing import Iterator
 from typing import Optional
 
@@ -431,6 +432,18 @@ class Datetime(_datetime):
         weekday_name = calendar.day_name[numeric_weekday]
         return weekday_name.lower()
 
+    def get_utc_offset(self) -> int:
+        """Get UTC offset in hours."""
+        offset = self.utcoffset()
+
+        if offset == _timedelta():
+            return 0
+
+        if offset:
+            return int(offset / _timedelta(hours=1))
+
+        raise ValueError("Error on getting UTC offset.")
+
     def is_today(self, weekday: str, week_start: Optional[str] = None) -> bool:
         """
         Check if the instance weekday is at a given weekday.
